@@ -60,9 +60,11 @@ type Parser struct {
 
 	CorePackerVersionString string
 
-	*hclparse.Parser
-
 	PluginConfig *packer.PluginConfig
+
+	ValidationOptions
+
+	*hclparse.Parser
 }
 
 const (
@@ -137,6 +139,8 @@ func (p *Parser) Parse(filename string, varFiles []string, argVars map[string]st
 		Basedir:                 basedir,
 		Cwd:                     wd,
 		CorePackerVersionString: p.CorePackerVersionString,
+		HCPVars:                 map[string]cty.Value{},
+		ValidationOptions:       p.ValidationOptions,
 		parser:                  p,
 		files:                   files,
 	}
